# Mapping genetic values to fitness

```{eval-rst}
.. autoclass:: fwdpy11.GeneticValueToFitnessMap
    :members:
```

```{eval-rst}
.. autoclass:: fwdpy11.GeneticValueIsTrait
```

```{eval-rst}
.. autoclass:: fwdpy11.GeneticValueIsFitness
```

```{eval-rst}
.. autoclass:: fwdpy11.Optimum
    :members: asdict, fromdict, asblack
```

```{eval-rst}
.. autoclass:: fwdpy11.PleiotropicOptima
    :members: asdict, fromdict, asblack
```


```{eval-rst}
.. autoclass:: fwdpy11.GaussianStabilizingSelection
    :members:
```


